
(define (domain satellite)
  (:requirements :strips :equality :typing :fluents :durative-actions :duration-inequalities :conditional-effects)
 (:types satellite direction instrument mode coolingstatus)
 (:predicates 
               (on_board ?i - instrument ?s - satellite)
	       (supports ?i - instrument ?m - mode)
	       (pointing ?s - satellite ?d - direction)
	(power_on ?i - instrument ?c - coolingstatus)
	(calibrated ?i - instrument ?d - direction ?c - coolingstatus)
	(idle ?i - instrument)
	       (have_image ?d - direction ?m - mode)
	       (calibration_target ?i - instrument ?d - direction)             
	       (canincrease) (candecrease) (increasing) (decreasing) (not-increasing) (not-decreasing) (canfinishincrease) (canfinishdecrease)
               (canfinishflat) (canflat) (flat) (not-flat)
	       (used ?i - instrument ?c - coolingstatus)
		(usable ?i - instrument ?c - coolingstatus ?d ?d2 - direction)
	      (want ?d - direction ?m - mode)
	      (anypower)
)
 
 

  (:functions (slew_time ?a ?b - direction)
	(multiplier ?c - coolingstatus)
            (calibration_time ?a - instrument ?d - direction)
		(data_capacity ?s - satellite)
		(data ?d - direction ?m - mode)
		(data-stored)
	       (power_avail ?s - satellite)
		(powered)

	)

(:durative-action power-increasing
:parameters ()
:duration (<= ?duration 2400)
:condition (and
  (at start (<= (powered) 1))
  (at start (canincrease))
  )
:effect
  (and
  (at start (increase (powered) 1))
  (at end (decrease (powered) 1))

  (at start (not (not-increasing)))  
  (at end (not-increasing))  

  (at start (increasing))
  (at end (not (increasing)))

  (at start (anypower))
  (at end (not (anypower)))

  (at start   (not (canincrease)))
  (at end     (not (canfinishincrease)))

  (forall (?s - satellite) (increase (power_avail ?s) (* #t 0.02)))
)
)

(:durative-action power-level
:parameters ()
:duration (= ?duration 10000)
:condition (and
  (at start (canflat))
  (at start (<= (powered) 1))
  )
:effect
  (and
  (at start (candecrease))
  (at start (canfinishincrease))

  (at start (increase (powered) 1))
  (at end (decrease (powered) 1))

  (at start (not (not-flat)))  
  (at end (not-flat))  

  (at start (flat))
  (at end (not (flat)))

  (at start   (not (canflat)))
  (at end     (not (canfinishflat)))

)
)




(:durative-action power-decreasing
:parameters ()
:duration (= ?duration 240)
:condition
(and
  (at start (candecrease))
  (at start (<= (powered) 1))
)
:effect
(and 

  (at start (canfinishflat))
  (at start (increase (powered) 1))
  (at end (decrease (powered) 1))
  (at start (not (not-decreasing)))  
  (at end (not-decreasing))  

  (at start (decreasing))
  (at end (not (decreasing)))

  (at start   (not (candecrease)))

  (forall (?s - satellite) (decrease (power_avail ?s) (* #t 0.05)))
)

)




 

  (:durative-action power_instrument
   :parameters (?s - satellite ?d - direction ?d2 - direction ?i - instrument ?m - mode ?c - coolingstatus)
   :duration (and (>= ?duration 2) (<= ?duration 10000))
   :condition (and    (over all (on_board ?i ?s))
                      (over all (supports ?i ?m))
                      (over all (>= (powered) 1))
                      (over all (anypower))
                      (at start (want ?d ?m))
                      (at start (calibration_target ?i ?d2))
                      (at start (pointing ?s ?d2))
                      (at end (have_image ?d ?m))
                      (at start (>= (power_avail ?s) (* (multiplier ?c) 2))) (at start (idle ?i))
                      (at end (used ?i ?c))
   )
   :effect (and (at start (power_on ?i ?c))
                (at start (not (want ?d ?m)))
                (at start (not (idle ?i)))
                (at end (not (power_on ?i ?c)))
                (at end (idle ?i))
                (at end (not (used ?i ?c)))
                (at start (not (pointing ?s ?d2)))
		(at start (usable ?i ?c ?d ?d2))
                (at start (decrease (power_avail ?s) (* (multiplier ?c) 2)))
                (at end (increase (power_avail ?s) (* (multiplier ?c) 2)))
           )

  )
  
  (:durative-action calibrate
   :parameters (?s - satellite ?i - instrument ?d ?d2 - direction ?c - coolingstatus)
   :duration (= ?duration (/ (calibration_time ?i ?d2) (multiplier ?c)))
   :condition (and (over all (on_board ?i ?s))(over all (>= (powered) 1))
                      (over all (calibration_target ?i ?d2))
                      (over all (power_on ?i ?c))
                      (over all (anypower))
			(at start (usable ?i ?c ?d ?d2))
                  )
   :effect (and
               (at start (not (usable ?i ?c ?d ?d2)))
                (at end (calibrated ?i ?d ?c))
                (at end (pointing ?s ?d2))
          )
  )

  (:durative-action take_image
   :parameters (?s - satellite ?d - direction ?i - instrument ?m - mode ?c - coolingstatus)
   :duration (= ?duration (/ 7 (multiplier ?c)))
   :condition (and (at start (calibrated ?i ?d ?c))(over all (>= (powered) 1))
                      (over all (on_board ?i ?s))
                      (over all (supports ?i ?m) )
                      (over all (power_on ?i ?c))
                      (over all (pointing ?s ?d))
                      (over all (anypower))
               )
   :effect (and
                (at end (have_image ?d ?m))
		(at start (not (calibrated ?i ?d ?c)))
		(at end (used ?i ?c))
                )
  )

  (:durative-action turn_to
   :parameters (?s - satellite ?d_new - direction ?d_prev - direction)
   :duration (= ?duration (slew_time ?d_prev ?d_new))
   :condition (and (at start (pointing ?s ?d_prev)) (at start (>= (powered) 1)) (over all (anypower))
              )
   :effect (and  (at end (pointing ?s ?d_new))
                 (at start (not (pointing ?s ?d_prev)))
           )
  )

)
